@@ -28,14 +28,19 @@
 #     Laura Swiler (Sandia National Labs)
 # <!-----------------END-HEADER------------------------------------->
 
-from .fitsnap import FitSnap
-from .parallel_tools import pt
-from .io.output import output
+from fitsnap3lib.fitsnap import FitSnap
+from fitsnap3lib.parallel_tools import ParallelTools
+from fitsnap3lib.io.output import output
+from fitsnap3lib.initialize import initialize_fitsnap_run
+
+
+pt = ParallelTools()
 
 
 @pt.single_timeit
 def main():
     try:
+        initialize_fitsnap_run()
         snap = FitSnap()
         snap.scrape_configs()
         snap.process_configs()
